# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-06-12 06:43
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0061_auto_20181221_1443'),
    ]

    operations = [
        migrations.AddField(
            model_name='video',
            name='file_name',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u89c6\u9891\u6587\u4ef6\u540d'),
        ),
    ]
