# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-16 09:57
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0065_auto_20190813_1743'),
    ]

    operations = [
        migrations.AddField(
            model_name='usercoursesection',
            name='learned_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u5f00\u59cb\u5b66\u4e60\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='minus_mins',
            field=models.IntegerField(default=0, verbose_name='\u6263\u51cf\u7684\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='passed_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u8bfe\u4ef6\u901a\u8fc7\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='send_message_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u7ed9\u52a9\u6559\u53d1\u6d88\u606f\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='teacher_add_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name='\u52a9\u6559\u64cd\u4f5c\u65f6\u95f4'),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='teacher_add_mins',
            field=models.IntegerField(blank=True, null=True, verbose_name='\u52a9\u6559\u589e\u52a0\u7684\u7ec3\u4e60\u65f6\u95f4'),
        ),
    ]
