# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-15 03:18
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course', '0035_auto_20180611_1624'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserSectionNote',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('note', models.TextField(verbose_name='\u7b14\u8bb0')),
                ('is_open', models.BooleanField(default=True, verbose_name='\u662f\u5426\u516c\u5f00')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('updated_at', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
        migrations.AlterField(
            model_name='section',
            name='has_videowork',
            field=models.BooleanField(default=True, verbose_name='\u662f\u5426\u9700\u8981\u89c6\u9891\u5f55\u5236'),
        ),
        migrations.AddField(
            model_name='usersectionnote',
            name='section',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Section'),
        ),
        migrations.AddField(
            model_name='usersectionnote',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]
