# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-30 08:15
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0081_userlive_is_certify'),
    ]

    operations = [
        migrations.AddField(
            model_name='userlive',
            name='ucs',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserCourseSection'),
        ),
    ]
