# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-04-01 11:23
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course', '0024_auto_20180331_1011'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserLive',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('provider_name', models.CharField(max_length=180)),
                ('cc_user_id', models.CharField(max_length=180, null=True)),
                ('room_id', models.CharField(max_length=180, null=True)),
                ('live_id', models.CharField(max_length=180, null=True)),
                ('stop_status', models.CharField(max_length=180, null=True)),
                ('record_status', models.CharField(max_length=180, null=True)),
                ('record_video_id', models.CharField(max_length=180, null=True)),
                ('replay_url', models.CharField(max_length=180, null=True)),
                ('start_time', models.DateTimeField(null=True)),
                ('end_time', models.DateTimeField(null=True)),
                ('duration', models.IntegerField(null=True)),
                ('record_video_duration', models.IntegerField(null=True)),
                ('status', models.IntegerField(default=1, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('call_count', models.IntegerField(default=0)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'user_live',
            },
        ),
    ]
