# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-15 06:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0029_auto_20180515_1301'),
    ]

    operations = [
        migrations.CreateModel(
            name='Preference',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('how_to_pass', models.IntegerField(default=0, verbose_name='\u8bfe\u7a0b\u901a\u8fc7\u6a21\u5f0f')),
            ],
        ),
    ]
