# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-03-28 07:54
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0020_auto_20180326_1358'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userassignment',
            options={'permissions': (('can_review', 'can review'),)},
        ),
    ]
