{% extends "bee_django_course/base.html" %}
{% block content %}
    <h4>视频详情</h4>
    <div class="video">
        {% if video_provider_name == 'cc' %}
            <iframe src="{{ video_src }}" frameborder="0" width="100%" height="100%"></iframe>
        {% elif video_provider_name == 'qiniu' %}
            <div align="center" class="embed-responsive embed-responsive-16by9">
                <video width='320' height='240' controls class="embed-responsive-item">
                    <source src="{{ video_src }}" type="video/mp4">
                    你的浏览器不支持video标签.
                </video>
            </div>
        {% endif %}
    </div>
    <h4>说明：</h4>
    <div>
        {{ video.info | default:'' | linebreaks }}
    </div>
{% endblock %}