# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-13 09:43
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0064_auto_20190710_1507'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='userlive',
            options={'ordering': ['-created_at'], 'permissions': (('view_all_userlives', '\u53ef\u4ee5\u67e5\u770b\u6240\u6709\u5b66\u751f\u7684\u5f55\u64ad'), ('view_teach_userlives', '\u53ef\u4ee5\u67e5\u770b\u6240\u6559\u7684\u5b66\u751f\u7684\u5f55\u64ad'), ('view_child_userlives', '\u53ef\u4ee5\u67e5\u770b\u4eb2\u5b50\u5b66\u751f\u7684\u5f55\u64ad'), ('view_expired_userlives', '\u53ef\u4ee5\u67e5\u770b\u8d85\u8fc7\u6307\u5b9a\u65f6\u95f4\u7684\u5f55\u64ad')), 'verbose_name': 'course\u5b66\u751f\u5f55\u64ad'},
        ),
    ]
