# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-19 06:14
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0066_auto_20190816_1757'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='usercoursesection',
            options={'ordering': ['-created_at'], 'permissions': [('view_all_usercoursesection', '\u67e5\u770b\u6240\u6709\u5b66\u751f\u8bfe\u4ef6'), ('view_teach_usercoursessection', '\u67e5\u770b\u6240\u6559\u7684\u5b66\u751f\u8bfe\u4ef6'), ('view_child_usercoursesection', '\u67e5\u770b\u4eb2\u5b50\u5b66\u751f\u8bfe\u4ef6'), ('pass_ucs', '\u80fd\u901a\u8fc7\u5b66\u751f\u8bfe\u4ef6'), ('close_ucs', '\u80fd\u5173\u95ed\u5b66\u751f\u8bfe\u4ef6'), ('open_ucs', '\u80fd\u5f00\u542f\u5b66\u751f\u8bfe\u4ef6'), ('minus_live_mins', '\u80fd\u6263\u51cf\u5b66\u751f\u76f4\u64ad\u65f6\u957f'), ('review_ucs', '\u80fd\u67e5\u770b\u5b66\u751f\u4f5c\u4e1a'), ('score_ucs', '\u80fd\u7ed9\u5b66\u751f\u4f5c\u4e1a\u8bc4\u5206')], 'verbose_name': 'course\u5b66\u751f\u8bfe\u4ef6'},
        ),
        migrations.RenameField(
            model_name='usercoursesection',
            old_name='minus_mins',
            new_name='minus_live_mins',
        ),
    ]
