# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-21 06:43
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0060_auto_20181219_1353'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='sectionquestion',
            options={'ordering': ['order_by'], 'permissions': (('view_sectionquestion', '\u53ef\u4ee5\u67e5\u770b\u95ee\u9898\u5217\u8868'),)},
        ),
    ]
