# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-06 07:38
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0049_sectionquestion_sectionquestionoption'),
    ]

    operations = [
        migrations.AddField(
            model_name='sectionquestion',
            name='options',
            field=models.ManyToManyField(to='bee_django_course.SectionQuestionOption'),
        ),
    ]
