# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-21 06:00
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0033_auto_20180517_1937'),
    ]

    operations = [
        migrations.CreateModel(
            name='SectionAttach',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file', models.FileField(upload_to='sections/%Y/%m/%d/', verbose_name='\u9644\u4ef6')),
                ('upload_at', models.DateTimeField(auto_now_add=True)),
                ('section', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.Section')),
            ],
        ),
        migrations.AddField(
            model_name='course',
            name='status',
            field=models.IntegerField(default=0, verbose_name='\u72b6\u6001'),
        ),
    ]
