# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-17 10:48
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0031_auto_20180516_1714'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='course',
            options={'ordering': ['-id'], 'permissions': (('can_manage_course', '\u53ef\u4ee5\u8fdb\u5165\u8bfe\u7a0b\u7ba1\u7406\u9875'), ('can_choose_course', 'can choose course')), 'verbose_name': 'course\u8bfe\u7a0b'},
        ),
    ]
