# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-09-11 07:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0071_userlive_is_mentor_view'),
    ]

    operations = [
        migrations.AddField(
            model_name='userlive',
            name='view_mentor_id',
            field=models.IntegerField(null=True),
        ),
    ]
