{% extends "bee_django_course/base.html" %}
{% load bootstrap3 %}
{% load bee_django_course_filter %}
{% block content %}
    学生：{{ user|get_name_detail:True|safe }}
    <table class="table">
        <thead>
        <tr>
            <th>序号</th>
            <th>日期</th>
            <th>时长</th>
            <th>查看</th>
            <th></th>
        </tr>
        </thead>
        <tbody>
        {% for e in lives %}
            <tr>
                <td>{{ forloop.counter }}</td>
                <td>{{ e.created_at }}</td>
                <td>{{ e.duration }}秒</td>
                <td>
                    {% if e.record_status == '10' %}
                        <a href="{% url 'bee_django_course:live_video_detail' user_live_id=e.id %}">查看</a>
                    {% elif e.record_status == '20' %}
                        录制失败
                    {% elif e.record_status == '30' %}
                        视频过长
                    {% else %}
                        转码中
                    {% endif %}
                </td>
            <td>
                <a href="#">
                    删除
                </a>
            </td>
            </tr>
        {% endfor %}
        </tbody>
    </table>

    {% load bootstrap_pagination %}
    {% bootstrap_paginate lives range=10 %}

{% endblock content %}