{% extends "bee_django_course/base.html" %}
{% load bootstrap3 %}
{% load bee_django_course_filter %}
{% block content %}

    <h3>
        作业管理（ 图片/文字/录播/问答 ）
    </h3>
    <div>
        <form method="get" action="">
            <input id="student_name" name="student_name" type="text" value="{{ request.GET.student_name }}"
                   placeholder="学生姓名..."/>

            <input type="submit" value="搜索"/>
        </form>
    </div>

    <table class="table">
        <thead>
        <tr>
            <th>课件</th>
            <th>学生</th>
            <th>开始日期</th>
            <th>更新日期</th>
            <th>查看</th>
        </tr>
        </thead>
        <tbody>
        {% for e in assignments %}
            <tr>
                <td>{{ e.section.name }}</td>
                <td>><a href="{{ live.user.get_user_search_link }}">{{ live.user }}</a></td>
                <td>{{ e.created_at }}</td>
                <td>{{ e.updated_at | default:'' }}</td>
                <td>
                    <a href="{% url 'bee_django_course:manage_user_assignment' ucs_id=e.id %}">查看</a>
                </td>
            </tr>
        {% endfor %}
        </tbody>
    </table>

    {% load bootstrap_pagination %}
    {% bootstrap_paginate assignments range=10 %}

{% endblock content %}