{% extends "bee_django_course/user_base.html" %}
{% load bee_django_course_filter %}
{% load bootstrap3 %}
{% block content %}
    {% include 'bee_django_course/custom_user/_user_course_list.html' %}
{% endblock %}