# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-19 05:53
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0059_userquestionanswerrecord'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='usercourse',
            options={'permissions': [('assign_user_course', '\u80fd\u7ed9\u5b66\u751f\u5206\u914d\u8bfe\u7a0b')]},
        ),
        migrations.AlterModelOptions(
            name='usercoursesection',
            options={'ordering': ['-created_at'], 'permissions': [('view_all_usercoursesection', '\u67e5\u770b\u6240\u6709\u5b66\u751f\u8bfe\u4ef6'), ('view_teach_usercoursessection', '\u67e5\u770b\u6240\u6559\u7684\u5b66\u751f\u8bfe\u4ef6'), ('pass_ucs', '\u80fd\u901a\u8fc7\u5b66\u751f\u8bfe\u4ef6'), ('close_ucs', '\u80fd\u5173\u95ed\u5b66\u751f\u8bfe\u4ef6'), ('open_ucs', '\u80fd\u5f00\u542f\u5b66\u751f\u8bfe\u4ef6'), ('review_ucs', '\u80fd\u67e5\u770b\u5b66\u751f\u4f5c\u4e1a'), ('score_ucs', '\u80fd\u7ed9\u5b66\u751f\u4f5c\u4e1a\u8bc4\u5206')], 'verbose_name': 'course\u5b66\u751f\u8bfe\u4ef6'},
        ),
    ]
