# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-07-10 07:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0063_auto_20190703_1608'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userlive',
            name='provider_name',
            field=models.CharField(default='cc', max_length=180),
        ),
    ]
