{% load bee_django_course_filter %}

<div>
    <div class="bg-black video_div">
        <iframe src="{{ e.video.video_id | get_video_src }}" frameborder="0" width="100%" height="100%"></iframe>
    </div>
    {{ e.video.info | default:'' | linebreaks }}
</div>