# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-29 07:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0078_auto_20191023_1625'),
    ]

    operations = [
        migrations.AddField(
            model_name='section',
            name='pass_cooldown',
            field=models.IntegerField(default=0, help_text='\u901a\u8fc7\u65f6\u8ddd\u79bb\u4e0a\u4e00\u8bfe\u4ef6\u7684\u95f4\u9694\u5929\u6570', verbose_name='\u95f4\u9694\u5929\u6570'),
        ),
    ]
