# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-12-27 07:25
from __future__ import unicode_literals

import bee_django_object_field.custom_fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course', '0079_section_pass_cooldown'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserCertifyRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.IntegerField(choices=[(0, '\u672a\u63d0\u4ea4'), (1, '\u5df2\u63d0\u4ea4'), (2, '\u901a\u8fc7'), (3, '\u9a73\u56de'), (4, '\u5173\u95ed')], default=0, verbose_name='\u72b6\u6001')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('operated_at', models.DateTimeField(blank=True, null=True, verbose_name='\u64cd\u4f5c\u65f6\u95f4')),
                ('detail', bee_django_object_field.custom_fields.DictField(blank=True, null=True, verbose_name='\u6dfb\u52a0\u65f6\u7684\u8be6\u7ec6\u6570\u636e')),
                ('operator', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='\u64cd\u4f5c\u8005')),
                ('user_course_section', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserCourseSection')),
            ],
            options={
                'ordering': ['-id'],
                'db_table': 'bee_django_course_user_certify_record',
            },
        ),
        migrations.AddField(
            model_name='section',
            name='need_certify',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u8ba4\u8bc1'),
        ),
    ]
