# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-03-23 10:42
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0014_auto_20180322_1313'),
    ]

    operations = [
        migrations.AddField(
            model_name='course',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AddField(
            model_name='section',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
