{% extends "bee_django_course/base.html" %}
{% load bee_django_course_filter %}

{% block content %}
    <div class="text-center"><h3>
        课程课件学习统计
    </h3>
    </div>
    <div style="margin: 10px auto;">
        {% include 'bee_django_course/report/ucs_search.html' %}
    </div>
    <table class="table table-bordered">
        <thead>
        <tr>
            <th>学生</th>
            <th>课程</th>
            <th>添加时间</th>
            <th>通过时间</th>
        </tr>
        </thead>
        <tbody>
        {% for uc in uc_list %}
            <tr>
                <td>
                    <a href="{{ uc.user.get_user_search_link }}">{{ uc.user }}</a>
                    <span style="color: red">{{ uc.user.get_user_status }}</span>
                </td>
                <td>
                    {{ uc.course.name }}

                </td>

                <td>
                    {{ uc.created_at|default:"" }}
                </td>
                <td>
                    {{ uc.passed_at|default:"" }}
                </td>
                {#                <td><a href="{% url 'bee_django_course:live_list' student.id %}">录播记录</a></td>#}

            </tr>
        {% endfor %}

        </tbody>
    </table>
    {% include 'bee_django_course/paginator.html' %}
{% endblock %}

{% block scripts %}

{% endblock %}