# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-03-22 05:13
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0013_auto_20180322_1240'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserAssignment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', models.TextField(blank=True, null=True, verbose_name='\u6b63\u6587')),
                ('work_time', models.IntegerField(blank=True, default=0, null=True, verbose_name='\u603b\u5171\u7ec3\u4e60\u65f6\u95f4')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('score', models.IntegerField(blank=True, null=True, verbose_name='\u5f97\u5206')),
                ('updated_at', models.DateTimeField(blank=True, null=True)),
                ('submit_at', models.DateTimeField(blank=True, null=True)),
                ('status', models.IntegerField(default=0)),
                ('comment', models.TextField(blank=True, null=True, verbose_name='\u8bc4\u8bed')),
                ('reviewed_at', models.DateTimeField(blank=True, null=True)),
                ('rejected_at', models.DateTimeField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='UserAssignmentImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(upload_to='images/%Y/%m/%d', verbose_name='\u56fe\u7247\u4f5c\u4e1a')),
                ('upload_at', models.DateTimeField(auto_now_add=True, verbose_name='\u4e0a\u4f20\u65f6\u95f4')),
                ('user_assignment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserAssignment')),
            ],
        ),
        migrations.RemoveField(
            model_name='userassignmenttext',
            name='user_course_section',
        ),
        migrations.RemoveField(
            model_name='usercoursesection',
            name='work_time',
        ),
        migrations.DeleteModel(
            name='UserAssignmentText',
        ),
        migrations.AddField(
            model_name='userassignment',
            name='user_course_section',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.UserCourseSection'),
        ),
    ]
