# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-15 04:54
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0027_auto_20180417_1459'),
    ]

    operations = [
        migrations.AddField(
            model_name='course',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to=b'', verbose_name='\u914d\u56fe'),
        ),
    ]
