# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-14 08:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0054_section_question_passed_at'),
    ]

    operations = [
        migrations.AddField(
            model_name='usercoursesection',
            name='question_passed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='usercoursesection',
            name='question_passed_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
