# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-10-23 08:25
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0077_auto_20191021_1603'),
    ]

    operations = [
        migrations.AlterField(
            model_name='section',
            name='has_to_finish_course_video',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u770b\u5b8c\u8bfe\u4ef6\u6240\u6709\u89c6\u9891'),
        ),
        migrations.AlterField(
            model_name='section',
            name='has_videowork',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u9700\u8981\u89c6\u9891\u5f55\u5236'),
        ),
    ]
