# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-08-21 05:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_course', '0067_auto_20190819_1414'),
    ]

    operations = [
        migrations.AddField(
            model_name='course',
            name='template',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u6a21\u7248'),
        ),
    ]
